/*
 * Copyright 2019 by its authors. See AUTHORS.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <Eo.h>

#define EOLIANCXXTEST_API
#define EOLIANCXXTEST_API_WEAK

#include "name_name.eo.h"
#include "name_name.eo.hh"
#include "ns_name.eo.h"
#include "ns_name.eo.hh"
#include "ns_name_other.eo.h"
#include "ns_name_other.eo.hh"

